# Embeddings


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**iterable** | [**List[Embedding]**](Embedding.md) |  | 

## Example

```python
from openapi_client.models.embeddings import Embeddings

# TODO update the JSON string below
json = "{}"
# create an instance of Embeddings from a JSON string
embeddings_instance = Embeddings.from_json(json)
# print the JSON string representation of the object
print Embeddings.to_json()

# convert the object into a dict
embeddings_dict = embeddings_instance.to_dict()
# create an instance of Embeddings from a dict
embeddings_form_dict = embeddings.from_dict(embeddings_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


